@@ -68,9 +68,8 @@
 #' fit5 <- step1_down(data = potency, y = "Potency", .time = "Time",C = "Celsius",
 #'   reparameterisation = TRUE, zero_order = TRUE, draw = 5000, lower = c(-Inf, 0, 0))
 #'
-#' @importFrom stats vcov coef runif confint rnorm quantile qt complete.cases
+#' @importFrom stats vcov coef runif confint rnorm rchisq quantile qt complete.cases
 #' @importFrom minpack.lm nls.lm
-#' @importFrom mvtnorm rmvt
 #'
 #' @export step1_down
 
@@ -95,7 +94,7 @@ step1_down <- function (data, y, .time, K = NULL, C = NULL, validation = NULL,
     confidence_interval = confidence_interval, by = by,
     reparameterisation = reparameterisation, zero_order = zero_order)
 
-  ## Additional arguments in the call will be passed to model fitting with minipak.lm
+  ## Additional arguments in the call will be passed to model fitting with minpack.lm
   minpack_args = list(...)                    ##
 
   ## Temperature: both C and K are provided
@@ -234,6 +233,8 @@ if (!"lower" %in% names(minpack_args)) 	{	##
     SIG = stats::vcov(fit)
     sigma = summary(fit)$sigma
     DF = summary(fit)$df[2]
+    n.params = summary(fit)$df[1]
+
     pred = expand.grid(time = times.pred, K = Temps)
     pred$Degradation = pred$time * exp(k1 - k2/pred$K + k2/Kref)
     pred$Response = c0 - c0 * pred$Degradation
@@ -254,16 +255,18 @@ if (!"lower" %in% names(minpack_args)) 	{	##
         conc = coef.fit[3] - coef.fit[3]*degrad
         return(conc)
       }
-      # Multi T bootstrap
-      rand.coef = mvtnorm::rmvt(draw, sigma = SIG, df = nrow(dat) - 3) + matrix(nrow = draw, ncol = 3, byrow = TRUE, coef(fit))
-      res.boot = matrix(nrow = draw, ncol = nrow(pred), byrow = TRUE, apply(rand.coef, 1, pred_fct))
+      # Multi T samples
+      rand.coef = matrix(nrow = n.params, ncol = draw, rnorm(n = n.params * draw, mean = 0, sd = 1))
+      rand.coef = t(coef(fit) + t(chol(SIG * DF / (DF - 2))) %*% rand.coef)
+      res.draw = matrix(nrow = draw, ncol = nrow(pred), byrow = TRUE, apply(rand.coef, 1, pred_fct))
 
-      CI1b = apply(res.boot, 2, quantile, ((1-confidence_interval)/2), na.rm = TRUE)
-      CI2b = apply(res.boot, 2, quantile, ((1+confidence_interval)/2), na.rm = TRUE)
+      CI1b = apply(res.draw, 2, quantile, ((1-confidence_interval)/2), na.rm = TRUE)
+      CI2b = apply(res.draw, 2, quantile, ((1+confidence_interval)/2), na.rm = TRUE)
 
-      res.boot = res.boot + rnorm(draw*length(pred$time), 0, sigma)
-      PI1b = apply(res.boot, 2, quantile, ((1-confidence_interval)/2), na.rm = TRUE)
-      PI2b = apply(res.boot, 2, quantile, ((1+confidence_interval)/2), na.rm = TRUE)
+      sigma.dist = sqrt((DF * sigma^2) / rchisq(n = draw*length(pred$time), df = DF))
+      res.draw = res.draw + rnorm(n = draw*length(pred$time), mean = 0, sd = sigma.dist)
+      PI1b = apply(res.draw, 2, quantile, ((1-confidence_interval)/2), na.rm = TRUE)
+      PI2b = apply(res.draw, 2, quantile, ((1+confidence_interval)/2), na.rm = TRUE)
     }
 
 ## Model type 2 - no reparameterisation and k3 = 0
@@ -333,6 +336,7 @@ if (!"lower" %in% names(minpack_args)) 	{	##
     SIG = vcov(fit)
     sigma = summary(fit)$sigma
     DF = summary(fit)$df[2]
+    n.params = summary(fit)$df[1]  
 
     pred = expand.grid("time" = times.pred, K = Temps)
     pred$Degradation = pred$time * exp(k1 - k2 / pred$K)
@@ -353,18 +357,18 @@ if (!"lower" %in% names(minpack_args)) 	{	##
         conc = coef.fit[3] - coef.fit[3]*degrad
         return(conc)
       }
-      # Multi T bootstrap
-      rand.coef = mvtnorm::rmvt(draw, sigma = SIG, df = nrow(dat) - 3) + matrix(nrow = draw, ncol = 3, byrow = TRUE, coef(fit))
-      res.boot = matrix(nrow = draw, ncol = nrow(pred), byrow = TRUE, apply(rand.coef, 1, pred_fct))
-
-      CI1b = apply(res.boot, 2, quantile, ((1-confidence_interval)/2), na.rm = TRUE)
-      CI2b = apply(res.boot, 2, quantile, ((1+confidence_interval)/2), na.rm = TRUE)
-
-      res.boot = res.boot + rnorm(draw*length(pred$time), 0, sigma)
-      PI1b = apply(res.boot, 2, quantile, ((1-confidence_interval)/2), na.rm = TRUE)
-      PI2b = apply(res.boot, 2, quantile, ((1+confidence_interval)/2), na.rm = TRUE)
+      # Multi T samples
+      rand.coef = matrix(nrow = n.params, ncol = draw, rnorm(n = n.params * draw, mean = 0, sd = 1))
+      rand.coef = t(coef(fit) + t(chol(SIG * DF / (DF - 2))) %*% rand.coef)
+      res.draw = matrix(nrow = draw, ncol = nrow(pred), byrow = TRUE, apply(rand.coef, 1, pred_fct))
 
+      CI1b = apply(res.draw, 2, quantile, ((1-confidence_interval)/2), na.rm = TRUE)
+      CI2b = apply(res.draw, 2, quantile, ((1+confidence_interval)/2), na.rm = TRUE)
 
+      sigma.dist = sqrt((DF * sigma^2) / rchisq(n = draw*length(pred$time), df = DF))
+      res.draw = res.draw + rnorm(n = draw*length(pred$time), mean = 0, sd = sigma.dist)
+      PI1b = apply(res.draw, 2, quantile, ((1-confidence_interval)/2), na.rm = TRUE)
+      PI2b = apply(res.draw, 2, quantile, ((1+confidence_interval)/2), na.rm = TRUE)
     }
 
 ## Model type 3 - reparameterisation and k3 is not zero
@@ -440,6 +444,7 @@ if (!"lower" %in% names(minpack_args)) 	{	##
     SIG = vcov(fit)
     sigma = summary(fit)$sigma
     DF = summary(fit)$df[2]
+    n.params = summary(fit)$df[1]
 
     pred = expand.grid("time" = times.pred, K = Temps)
     pred$Degradation = 1 - ((1 - k3) * (1/(1 - k3) - pred$time * exp(k1 - k2 / pred$K + k2 / Kref)))^(1/(1-k3))
@@ -461,23 +466,23 @@ if (!"lower" %in% names(minpack_args)) 	{	##
         conc = coef.fit[4] - coef.fit[4]*degrad
         return(conc)
       }
-      # Multi T bootstrap
-      rand.coef = mvtnorm::rmvt(draw, sigma = SIG, df = nrow(dat) - 4) + matrix(nrow = draw, ncol = 4, byrow = TRUE, coef(fit))
-      res.boot = matrix(nrow = draw, ncol = nrow(pred), byrow = TRUE, apply(rand.coef, 1, pred_fct))
+      # Multi T samples
+      rand.coef = matrix(nrow = n.params, ncol = draw, rnorm(n = n.params * draw, mean = 0, sd = 1))
+      rand.coef = t(coef(fit) + t(chol(SIG * DF / (DF - 2))) %*% rand.coef)
+      res.draw = matrix(nrow = draw, ncol = nrow(pred), byrow = TRUE, apply(rand.coef, 1, pred_fct))
 
       no_k3_below0 <- sum(rand.coef[,3] < 0)
       if(no_k3_below0 > 0.5){
-        cat(paste(paste0(no_k3_below0*100/draw, "% of the bootstraps for k3 are below zero, this might have an adverse effect on the confidence interval, particularly if this value exceeds the confidence %."),"We suggest considering option zero_order = TRUE", sep = "\n"))
+        cat(paste(paste0(no_k3_below0*100/draw, "% of the draws for k3 are below zero, this might have an adverse effect on the confidence interval, particularly if this value exceeds the confidence %."),"We suggest considering option zero_order = TRUE", sep = "\n"))
       }
 
-      CI1b = apply(res.boot, 2, quantile, ((1-confidence_interval)/2), na.rm = TRUE)
-      CI2b = apply(res.boot, 2, quantile, ((1+confidence_interval)/2), na.rm = TRUE)
-
-      res.boot = res.boot + rnorm(draw*length(pred$time), 0, sigma)
-      PI1b = apply(res.boot, 2, quantile, ((1-confidence_interval)/2), na.rm = TRUE)
-      PI2b = apply(res.boot, 2, quantile, ((1+confidence_interval)/2), na.rm = TRUE)
-
+      CI1b = apply(res.draw, 2, quantile, ((1-confidence_interval)/2), na.rm = TRUE)
+      CI2b = apply(res.draw, 2, quantile, ((1+confidence_interval)/2), na.rm = TRUE)
 
+      sigma.dist = sqrt((DF * sigma^2) / rchisq(n = draw*length(pred$time), df = DF))
+      res.draw = res.draw + rnorm(n = draw*length(pred$time), mean = 0, sd = sigma.dist)
+      PI1b = apply(res.draw, 2, quantile, ((1-confidence_interval)/2), na.rm = TRUE)
+      PI2b = apply(res.draw, 2, quantile, ((1+confidence_interval)/2), na.rm = TRUE)
     }
 
 ## Model type 4 - no reparameterisation and k3 is not 0
@@ -551,6 +556,7 @@ if (!"lower" %in% names(minpack_args)) 	{	##
     SIG = vcov(fit)
     sigma = summary(fit)$sigma
     DF = summary(fit)$df[2]
+    n.params = summary(fit)$df[1]
 
     pred = expand.grid("time" = times.pred, K = Temps)
     pred$Degradation = 1 - ((1 - k3) * (1/(1 - k3) - pred$time * exp(k1 - k2 / pred$K)))^(1/(1-k3))
@@ -571,21 +577,23 @@ if (!"lower" %in% names(minpack_args)) 	{	##
         conc = coef.fit[4] - coef.fit[4]*degrad
         return(conc)
       }
-      # Multi T bootstrap
-      rand.coef = mvtnorm::rmvt(draw, sigma = SIG, df = nrow(dat) - 4) + matrix(nrow = draw, ncol = 4, byrow = TRUE, coef(fit))
-      res.boot = matrix(nrow = draw, ncol = nrow(pred), byrow = TRUE, apply(rand.coef, 1, pred_fct))
+      # Multi T samples
+      rand.coef = matrix(nrow = n.params, ncol = draw, rnorm(n = n.params * draw, mean = 0, sd = 1))
+      rand.coef = t(coef(fit) + t(chol(SIG * DF / (DF - 2))) %*% rand.coef)
+      res.draw = matrix(nrow = draw, ncol = nrow(pred), byrow = TRUE, apply(rand.coef, 1, pred_fct))
 
       no_k3_below0 <- sum(rand.coef[,3] < 0)
       if(no_k3_below0 > 0.5){
-        cat(paste(paste0(no_k3_below0*100/draw, "% of the bootstraps for k3 are below zero, this might have an adverse effect on the confidence interval, particularly if this value exceeds the confidence %."),"We suggest considering option zero_order = TRUE", sep = "\n"))
+        cat(paste(paste0(no_k3_below0*100/draw, "% of the draws for k3 are below zero, this might have an adverse effect on the confidence interval, particularly if this value exceeds the confidence %."),"We suggest considering option zero_order = TRUE", sep = "\n"))
       }
 
-      CI1b = apply(res.boot, 2, quantile, ((1-confidence_interval)/2), na.rm = TRUE)
-      CI2b = apply(res.boot, 2, quantile, ((1+confidence_interval)/2), na.rm = TRUE)
+      CI1b = apply(res.draw, 2, quantile, ((1-confidence_interval)/2), na.rm = TRUE)
+      CI2b = apply(res.draw, 2, quantile, ((1+confidence_interval)/2), na.rm = TRUE)
 
-      res.boot = res.boot + rnorm(draw*length(pred$time), 0, sigma)
-      PI1b = apply(res.boot, 2, quantile, ((1-confidence_interval)/2), na.rm = TRUE)
-      PI2b = apply(res.boot, 2, quantile, ((1+confidence_interval)/2), na.rm = TRUE)
+      sigma.dist = sqrt((DF * sigma^2) / rchisq(n = draw*length(pred$time), df = DF))
+      res.draw = res.draw + rnorm(n = draw*length(pred$time), mean = 0, sd = sigma.dist)
+      PI1b = apply(res.draw, 2, quantile, ((1-confidence_interval)/2), na.rm = TRUE)
+      PI2b = apply(res.draw, 2, quantile, ((1+confidence_interval)/2), na.rm = TRUE)
     }
 
 
